<template>
  <div class="info-station">
    <div class="header">
      <div class="title">
        <i class="icon"></i>
        <div class="info">
          <span class="name">{{ title }}</span>
          <div class="tool">
            <van-button class="btn" plain hairline type="info" size="mini" @click="dispatch">周边调度</van-button>
            <van-button class="btn" plain hairline type="info" size="mini" @click="getRails">电子围栏</van-button>
          </div>
        </div>
      </div>
      <div class="more" @click="showContent = !showContent">
        <span>{{ showContent ? "收起" : "更多" }}</span>
        <i class="icon" :class="[showContent ? 'icon-hide' : 'icon-more']"></i>
      </div>
    </div>
    <div v-show="showContent" class="content">
      <div class="info">
        <div class="detail">
          <span class="label">公司名称：</span>
          <span class="value value-link" @click="toCompany">{{ companyName }}</span>
        </div>
        <div class="detail">
          <span class="label">负责人员：</span>
          <span class="value">{{ principalName }}</span>
        </div>
        <div class="detail">
          <span class="label">联系方式：</span>
          <span v-if="!concatVisible" class="value">{{ contactHide }}</span>
          <span v-if="concatVisible" class="value">{{ principalContact }}</span>
          <span class="visible" @click="concatVisible = !concatVisible">{{ contactVisibleName }}</span>
        </div>
        <div class="detail">
          <span class="label">服务对象名称：</span>
          <span class="value">{{ serviceScope }}</span>
        </div>
        <div class="detail">
          <span class="label">驻勤点监管机构：</span>
          <span class="value">{{ superviseDepartName }}</span>
        </div>
        <div class="detail">
          <span class="label">驻勤点地址：</span>
          <span class="value">{{ address }}</span>
        </div>
        <div class="detail">
          <span class="label">驻勤人数：</span>
          <span class="value value-link" @click="clickStationEmployees">{{ countOfSecurityMan }}</span>
        </div>
        <div class="detail">
          <span class="label">驻勤点类型：</span>
          <span class="value">{{ stationTypeName }}</span>
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import { Button } from "vant";
import { searchRail } from "@/api/security-station-rails-controller";

export default {
  name: "infoStation",
  components: {
    [Button.name]: Button,
  },
  props: {
    data: Object,
  },
  data() {
    return {
      showContent: false,
      idVisible: false,
      concatVisible: false,
    };
  },
  computed: {
    title() {
      return `${this.data?.name}`;
    },
    companyName() {
      return this.data?.companyName || ";";
    },
    principalName() {
      return this.data?.principalName || "";
    },
    contactVisibleName() {
      return this.concatVisible ? "隐藏" : "显示";
    },
    contactHide() {
      return "***********";
    },
    principalContact() {
      return this.data?.principalContact || "";
    },
    serviceScope() {
      return this.data?.serviceScope || "";
    },
    superviseDepartName() {
      return this.data?.superviseDepartName || "";
    },
    address() {
      return this.data?.address || "";
    },
    countOfSecurityMan() {
      return this.data?.countOfSecurityMan || 0;
    },
    stationTypeName() {
      return this.data.stationTypes && this.data.stationTypes.length > 0 ? this.data.stationTypes[0].name : "";
    },
  },
  methods: {
    toCompany() {
      this.$emit("toCompany", this.data, "station");
    },
    clickStationEmployees() {
      this.$emit("clickStationEmployees", this.data);
    },
    dispatch() {
      const data = {
        ...this.data,
        from: "station",
      };
      this.$emit("dispatch", data);
    },
    getRails() {
      searchRail({
        pageIndex: 0,
        pageSize: 0,
        searchModel: "Station",
        stationId: this.data.id,
      })
        .then((res) => {
          console.log("searchRail", res);
          if (res) {
            this.$emit("railList", res);
          }
        })
        .catch((err) => {
          console.log(err);
        });
    },
  },
};
</script>

<style scoped lang="less">
.info-station {
  .header {
    width: 100%;
    height: 85px;
    background: #ffffff;
    padding: 0 20px;
    box-sizing: border-box;
    display: flex;
    align-items: center;
    justify-content: space-between;
    .title {
      display: flex;
      align-items: center;
      .icon {
        display: block;
        width: 36px;
        height: 36px;
        background: url("~@/assets/images/mapSearch/驻勤点备份.png") no-repeat;
        background-size: 100% 100%;
      }
      .info {
        height: 48px;
        display: flex;
        flex-direction: column;
        justify-content: space-between;
        margin-left: 8px;
        .name {
          font-size: 14px;
          font-family: PingFang SC-Medium, PingFang SC;
          font-weight: 500;
          color: #303133;
          line-height: 22px;
        }
        .tool {
          height: 22px;
          display: flex;
          flex-direction: row;
          .btn {
            margin-right: 12px;
          }
        }
      }
    }
    .more {
      width: 68px;
      height: 26px;
      border-radius: 24px;
      border: 1px solid #dcdfe6;
      display: flex;
      align-items: center;
      justify-content: space-between;
      padding: 0 10px;
      span {
        font-size: 14px;
        font-family: PingFang SC-Regular, PingFang SC;
        font-weight: 400;
        color: #303133;
      }
      .icon {
        display: block;
        width: 16px;
        height: 16px;
        &-hide {
          background: url("~@/assets/images/common/下.png") no-repeat;
          background-size: 100% 100%;
        }
        &-more {
          background: url("~@/assets/images/common/右.png") no-repeat;
          background-size: 100% 100%;
        }
      }
    }
  }
  .content {
    width: 100%;
    .info {
      width: 100%;
      padding: 12px 20px;
      .detail {
        width: 100%;
        display: flex;
        align-items: center;
        margin-bottom: 10px;
        &:last-child {
          margin-bottom: 0;
        }
        .label {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC, serif;
          font-weight: 400;
          color: #909399;
        }

        .value {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #303133;
          &-link {
            font-size: 12px;
            font-family: PingFang SC-Regular, PingFang SC;
            font-weight: 400;
            color: #0f71ff;
            text-decoration: underline;
          }
        }
        .visible {
          font-size: 12px;
          font-family: PingFang SC-Regular, PingFang SC;
          font-weight: 400;
          color: #0f71ff;
          margin-left: 2px;
        }
      }
    }
    .dispatch {
      width: 100%;
      padding: 8px 20px;
      .title {
        font-size: 12px;
        line-height: 22px;
        font-family: PingFang SC-Medium, PingFang SC, serif;
        font-weight: 500;
        color: #3d3d3d;
        margin-bottom: 10px;
      }
      .btn-list {
        display: flex;
        flex-direction: row;
        flex-wrap: wrap;
        .btn {
          margin-bottom: 14px;
          margin-right: 20px;
          width: 88px;
          //border-radius: 6px 6px 6px 6px;
        }
      }
    }
  }
}
</style>
